# coding=utf-8
# Copyright 2022 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""bucc dataset."""

from tensorflow_datasets.datasets.bucc import bucc_dataset_builder
import tensorflow_datasets.public_api as tfds


class BuccTest(tfds.testing.DatasetBuilderTestCase):
  """Tests for bucc dataset."""

  DATASET_CLASS = bucc_dataset_builder.Builder
  BUILDER_CONFIG_NAMES_TO_TEST = ['bucc_fr']
  SPLITS = {
      'validation': 3,  # Number of fake validation example
      'test': 1,  # Number of fake test example
  }

  DL_EXTRACT_RESULT = {
      'bucc_test_dir': 'test-gold',
      'bucc_dev_dir': 'training-gold',
  }


if __name__ == '__main__':
  tfds.testing.test_main()
